Struct XButtonEvent
#[repr(C)]pub struct XButtonEvent {}Fields
type_: i32serial: u64send_event: i32display: *mut _XDisplaywindow: u64root: u64subwindow: u64time: u64x: i32y: i32x_root: i32y_root: i32state: u32same_screen: i32Trait Implementations
impl AsMut<XButtonEvent> for XEvent
impl AsMut<XButtonEvent> for XEvent
fn as_mut(&mut self) -> &mut XButtonEvent
fn as_mut(&mut self) -> &mut XButtonEvent
Converts this type into a mutable reference of the (usually inferred) input type.
impl AsRef<XButtonEvent> for XEvent
impl AsRef<XButtonEvent> for XEvent
fn as_ref(&self) -> &XButtonEvent
fn as_ref(&self) -> &XButtonEvent
Converts this type into a shared reference of the (usually inferred) input type.
impl Clone for XButtonEvent
impl Clone for XButtonEvent
fn clone(&self) -> XButtonEvent
fn clone(&self) -> XButtonEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for XButtonEvent
impl Debug for XButtonEvent
impl Debug for XButtonEvent
impl<'a> From<&'a XButtonEvent> for XEvent
impl<'a> From<&'a XButtonEvent> for XEvent
fn from(other: &'a XButtonEvent) -> XEvent
fn from(other: &'a XButtonEvent) -> XEvent
Converts to this type from the input type.
impl<'a> From<&'a XEvent> for XButtonEvent
impl<'a> From<&'a XEvent> for XButtonEvent
fn from(xevent: &'a XEvent) -> XButtonEvent
fn from(xevent: &'a XEvent) -> XButtonEvent
Converts to this type from the input type.
impl From<XButtonEvent> for XEvent
impl From<XButtonEvent> for XEvent
fn from(other: XButtonEvent) -> XEvent
fn from(other: XButtonEvent) -> XEvent
Converts to this type from the input type.
impl From<XEvent> for XButtonEvent
impl From<XEvent> for XButtonEvent
fn from(xevent: XEvent) -> XButtonEvent
fn from(xevent: XEvent) -> XButtonEvent
Converts to this type from the input type.
impl PartialEq for XButtonEvent
impl PartialEq for XButtonEvent
impl StructuralPartialEq for XButtonEvent