Struct XSelectionClearEvent
#[repr(C)]pub struct XSelectionClearEvent {
pub type_: i32,
pub serial: u64,
pub send_event: i32,
pub display: *mut _XDisplay,
pub window: u64,
pub selection: u64,
pub time: u64,
}Fields
type_: i32serial: u64send_event: i32display: *mut _XDisplaywindow: u64selection: u64time: u64Trait Implementations
impl AsMut<XSelectionClearEvent> for XEvent
impl AsMut<XSelectionClearEvent> for XEvent
fn as_mut(&mut self) -> &mut XSelectionClearEvent
fn as_mut(&mut self) -> &mut XSelectionClearEvent
Converts this type into a mutable reference of the (usually inferred) input type.
impl AsRef<XSelectionClearEvent> for XEvent
impl AsRef<XSelectionClearEvent> for XEvent
fn as_ref(&self) -> &XSelectionClearEvent
fn as_ref(&self) -> &XSelectionClearEvent
Converts this type into a shared reference of the (usually inferred) input type.
impl Clone for XSelectionClearEvent
impl Clone for XSelectionClearEvent
fn clone(&self) -> XSelectionClearEvent
fn clone(&self) -> XSelectionClearEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for XSelectionClearEvent
impl Debug for XSelectionClearEvent
impl Debug for XSelectionClearEvent
impl<'a> From<&'a XEvent> for XSelectionClearEvent
impl<'a> From<&'a XEvent> for XSelectionClearEvent
fn from(xevent: &'a XEvent) -> XSelectionClearEvent
fn from(xevent: &'a XEvent) -> XSelectionClearEvent
Converts to this type from the input type.
impl<'a> From<&'a XSelectionClearEvent> for XEvent
impl<'a> From<&'a XSelectionClearEvent> for XEvent
fn from(other: &'a XSelectionClearEvent) -> XEvent
fn from(other: &'a XSelectionClearEvent) -> XEvent
Converts to this type from the input type.
impl From<XEvent> for XSelectionClearEvent
impl From<XEvent> for XSelectionClearEvent
fn from(xevent: XEvent) -> XSelectionClearEvent
fn from(xevent: XEvent) -> XSelectionClearEvent
Converts to this type from the input type.
impl From<XSelectionClearEvent> for XEvent
impl From<XSelectionClearEvent> for XEvent
fn from(other: XSelectionClearEvent) -> XEvent
fn from(other: XSelectionClearEvent) -> XEvent
Converts to this type from the input type.
impl PartialEq for XSelectionClearEvent
impl PartialEq for XSelectionClearEvent
impl StructuralPartialEq for XSelectionClearEvent